package dev.fitko.fitconnect.api.config;

import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.util.Collections;
import java.util.List;

@Data
@AllArgsConstructor
@NoArgsConstructor
public class Environment {

    private String authBaseUrl;
    private String routingBaseUrl;
    private List<String> submissionBaseUrls = Collections.emptyList();
    private String selfServicePortalBaseUrl;

    private Boolean enableAutoReject = true;
    private Boolean allowInsecurePublicKey = false;
    private Boolean skipSubmissionDataValidation = false;

    /**
     * Merges current env with provided other env.
     * If a field of the current env is null or empty, the value from other will be set.
     *
     * @param other environment to merge the current environment with
     * @return merged environment
     */
    public Environment merge(final Environment other){

        final Environment mergedEnv = new Environment();

        mergedEnv.setAuthBaseUrl(isNullOrEmpty(authBaseUrl) ? other.getAuthBaseUrl() : authBaseUrl);
        mergedEnv.setRoutingBaseUrl(isNullOrEmpty(routingBaseUrl) ? other.getRoutingBaseUrl() : routingBaseUrl);
        mergedEnv.setSubmissionBaseUrls(submissionBaseUrls.isEmpty() ? other.getSubmissionBaseUrls() : submissionBaseUrls);
        mergedEnv.setSelfServicePortalBaseUrl(isNullOrEmpty(selfServicePortalBaseUrl) ? other.getSelfServicePortalBaseUrl() : selfServicePortalBaseUrl);

        mergedEnv.setEnableAutoReject(enableAutoReject == null ? other.getEnableAutoReject() : enableAutoReject);
        mergedEnv.setAllowInsecurePublicKey(allowInsecurePublicKey == null ? other.getAllowInsecurePublicKey() : allowInsecurePublicKey);
        mergedEnv.setSkipSubmissionDataValidation(skipSubmissionDataValidation == null ? other.getSkipSubmissionDataValidation() : skipSubmissionDataValidation);

        return mergedEnv;
    }

    private boolean isNullOrEmpty(final String s){
        return s == null || s.isEmpty();
    }

}
